summaryrefslogtreecommitdiffstats
path: root/testpar/t_span_tree.c
diff options
context:
space:
mode:
authorDana Robinson <derobins@hdfgroup.org>2020-07-16 19:16:05 (GMT)
committerDana Robinson <derobins@hdfgroup.org>2020-07-16 19:16:05 (GMT)
commit02762e8244741b9ff1f9203788e7237f53cf8d96 (patch)
tree9ddfe80514742123b191b1b38ec0d885ff819e63 /testpar/t_span_tree.c
parent1ecb6ec9c5075a97572d06a1f509cd763be2bc94 (diff)
downloadhdf5-02762e8244741b9ff1f9203788e7237f53cf8d96.zip
hdf5-02762e8244741b9ff1f9203788e7237f53cf8d96.tar.gz
hdf5-02762e8244741b9ff1f9203788e7237f53cf8d96.tar.bz2
Merge of dataspace improvements from develop.
Diffstat (limited to 'testpar/t_span_tree.c')
-rw-r--r--testpar/t_span_tree.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/testpar/t_span_tree.c b/testpar/t_span_tree.c
index 0466839..eb3b0f7 100644
--- a/testpar/t_span_tree.c
+++ b/testpar/t_span_tree.c
@@ -2289,11 +2289,11 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size,
large_sel_start);
/* verify that H5S_select_shape_same() reports the two
* selections as having the same shape.
*/
- check = H5S_select_shape_same_test(mem_large_ds_sid, file_small_ds_sid);
- VRFY((check == TRUE), "H5S_select_shape_same_test passed (1)");
+ check = H5Sselect_shape_same(mem_large_ds_sid, file_small_ds_sid);
+ VRFY((check == TRUE), "H5Sselect_shape_same passed (1)");
ret = H5Dread(small_dataset,
@@ -2409,11 +2409,11 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size,
large_sel_start);
/* verify that H5S_select_shape_same() reports the two
* selections as having the same shape.
*/
- check = H5S_select_shape_same_test(mem_small_ds_sid, file_large_ds_sid);
- VRFY((check == TRUE), "H5S_select_shape_same_test passed (2)");
+ check = H5Sselect_shape_same(mem_small_ds_sid, file_large_ds_sid);
+ VRFY((check == TRUE), "H5Sselect_shape_same passed (2)");
ret = H5Dread(large_dataset,
@@ -2289,11 +2289,11 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size,
large_sel_start);
- /* verify that H5S_select_shape_same() reports the two
+ /* verify that H5Sselect_shape_same() reports the two
* selections as having the same shape.
*/
@@ -2409,11 +2409,11 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size,
large_sel_start);
- /* verify that H5S_select_shape_same() reports the two
+ /* verify that H5Sselect_shape_same() reports the two
* selections as having the same shape.
*/